@@ -8,9 +8,6 @@ class DemoAPP(object):
 
     def __init__(self):
         self.base_url = 'http://httpbin.org/'
-        self.headers = {
-            'b': 'asdf'
-        }
 
     @request(url='get')
     def get(self, value):
@@ -27,7 +24,5 @@ class TestApi(unittest.TestCase):
         cls.app = DemoAPP()
 
     def test_get(self):
-        res = self.app.get(123)
-        print res.get_params()
-        res.json
-        res.content
+        res = self.app.get(123).json
+        assert res.args.key == '123'
